@@ -169,7 +169,7 @@ class CANdoBus(BusABC):
         self.set_mode(CANdoMode.CANDO_NORMAL_MODE)
 
         self.filters_active = False
-        # Will be set to True if filters are set
+        # Will be set to True if filters are correctly set
         self.set_filters(can_filters)
 
         self.flush_buffers()
@@ -758,8 +758,8 @@ class CANdoBus(BusABC):
                     data=msg[5],
                     channel=self.channel,
                 ),
-                # If we get a message, it was certainly filtered!
-                True,
+                # Filters weren't set => all messages are received
+                self.filters_active,
             )
         except Empty:
             return (None, False)
@@ -907,14 +907,6 @@ def main() -> None:
 
     bus = CANdoBus(selected)
 
-    # can_filters = [
-    #     {"can_mask": 0x7FF, "can_id": 0x0, "extended": False},
-    #     {"can_mask": 0x1FFF0000, "can_id": 0x1500, "extended": True},
-    #     {"can_mask": 0x1FFF0000, "can_id": 0x18DA0000, "extended": True},
-    # ]
-
-    # bus.set_filters(can_filters)  # type: ignore
-
     try:
         while True:
             _in = input(
